--[[ Gear Aug Checker by MrInfernal v1.8

/augcheck <empty|filled|all> *<augtype#>*

ex: /augcheck empty
    /augcheck empty 9
    /augcheck all

Look through worn gear to return aug slots that are empty or tell you if they are empty/filled
Can sort by a type number

Close program with exit, close, or stop
ex: /augcheck stop
]]

local mq = require('mq')

local run = true

local gearSlotVis = {
    'head', -- 1
    'arms',
    'leftwrist',
    'rightwrist',
    'hands',  -- 5
    'chest',
    'legs',
    'feet',  -- 8
}

local gearSlotNonVis = {
    'leftear', -- 1
    'rightear',
    'face',
    'neck',
    'shoulder',  -- 5
    'back',
    'leftfinger',
    'rightfinger',
    'waist',
    'charm',  -- 10
}

local gearSlotWep = {
    'mainhand',
    'offhand',
    'ranged'
}

local function ShowHelp(useargs)
    print('Aug Checker by \arMrInfernal ')
    if useargs == 0 then
        print('\nUsage: \ao/augcheck \ax<\arempty\ax|\agfilled\ax|\agall\ax> \at<augtype#> \ay<stat>') 
    else
        print('\nUsage: \ao/lua run augcheck \ax<\arempty\ax|\agfilled\ax|\agall\ax> \at<augtype#>') 
    end
    print('\arEmpty\ax, \agFilled\ax, or \agAll \ax-- Only \arEmpty \axor \agFilled \axslots or \arEmpty\ax/\agFilled')
    print('\atAugType#\ax: Type number \ax-- \ay(Optional) \axOnly search this slot type')
    print('\ayStat\ax: Check by AC, HP, or by Heroic stat\n')
    print('Ex: \ao/lua run augcheck \agfilled \at9 \aydex \ax\ax\ax\ax-- To check filled Type 9 with hDex')
    --print('\nRun \ao/augcheck <augslot> \axwith an augment on cursor -- Check for slots that fit')
    if useargs == 0 then print('\n \ao/augcheck help \ax-- Show this help message again\n') end
end

local function runCheck(target, arg2, arg3)
    local augStats = {'AC', 'HP', 'STR', 'DEX', 'STA', 'AGI', 'INT', 'WIS', 'CHA'}
    local stat = ''
    local typenum = tonumber(arg2)
    local doStatCheck = false

    if arg3 ~= nil and table.concat(augStats):find(string.upper(arg3)) then
        stat = string.upper(arg3)
        doStatCheck = true
    end
    
    if target == 'exit' or target == 'stop' or target == 'close' then
        mq.unbind('/augcheck')
        run = false
    elseif target == 'help' then
        ShowHelp()

    elseif target == 'all' and typenum ~= nil and typenum > 0 and typenum <= 22 and doStatCheck then -- Check all for type# and stat
        printf('Displaying status of all type %d slots with %s\n', typenum, stat)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end

    elseif target == 'all' and typenum ~= nil and typenum > 0 and typenum <= 22 and not doStatCheck then -- Check all for type# w/link
        printf('Displaying status of all type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                        elseif not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end

    elseif target == 'filled' and typenum ~= nil and typenum > 0 and typenum <= 22 and doStatCheck then -- Check filled for type# and stat
        printf('Displaying status of Filled type %d slots with %s\n', typenum, stat)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local statCheck = 0
                            if stat == 'AC' then
                                statCheck = gear.AugSlot(i).Item.AC()
                            elseif stat == 'HP' then
                                statCheck = gear.AugSlot(i).Item.HP()
                            elseif stat == 'STR' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTR()
                            elseif stat == 'DEX' then
                                statCheck = gear.AugSlot(i).Item.HeroicDEX()
                            elseif stat == 'STA' then
                                statCheck = gear.AugSlot(i).Item.HeroicSTA()
                            elseif stat == 'AGI' then
                                statCheck = gear.AugSlot(i).Item.HeroicAGI()
                            elseif stat == 'INT' then
                                statCheck = gear.AugSlot(i).Item.HeroicINT()
                            elseif stat == 'WIS' then
                                statCheck = gear.AugSlot(i).Item.HeroicWIS()
                            elseif stat == 'CHA' then
                                statCheck = gear.AugSlot(i).Item.HeroicCHA()
                            end
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. stat .. ': ' .. statCheck
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end

    elseif target == 'filled' and typenum ~= nil and typenum > 0 and typenum <= 22 then -- Check filled type# slot w/ link
        printf('Displaying filled type %d slots\n', typenum)
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '

            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
  
    elseif target == 'empty' and typenum ~= nil and typenum > 0 and typenum <= 22 then -- Empty type# slots
        printf('Displaying empty type %d slots\n', typenum)
        local gearNum = 0
        for _, item in ipairs(gearSlotVis) do
            local gearSlots = {}
            local gear = mq.TLO.Me.Inventory(item)
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '

            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType == typenum then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        if gearNum == 0 then
            printf('No empty Type %d slots found', typenum)
        end
    
    elseif target == 'all' then -- Show Empty/Filled w/link
    print('Displaying Fill status for all aug slots\n')
    local gearSlots = {}
    for _, item in ipairs(gearSlotVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotNonVis) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end
    for _, item in ipairs(gearSlotWep) do
        local gear = mq.TLO.Me.Inventory(item)
        local gearSlots = {}
        local itemName = item .. ': '
        if gear.ID() then
            for i=1, 6 do
                local gearType = gear.AugSlot(i).Type()
                if gearType > 2 then
                    if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                        table.insert(gearSlots, aug)
                    elseif not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                        local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                        table.insert(gearSlots, aug)
                    end
                end
            end
            if #gearSlots > 0 then
                print(itemName, table.concat(gearSlots, ','))
            end
        end
    end

    elseif target == 'filled' then -- Show Filled with link
        print('Displaying Filled status for all aug slots\n')
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if not gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): ' .. gear.AugSlot(i).Item.ItemLink('CLICKABLE')()
                            table.insert(gearSlots, aug)
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end

    else -- Default. Only show Empty
        print('Only displaying Empty aug slots\n')
        local gearNum = 0
        for _, item in ipairs(gearSlotVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotNonVis) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        for _, item in ipairs(gearSlotWep) do
            local gear = mq.TLO.Me.Inventory(item)
            local gearSlots = {}
            local itemName = item .. ': '
            if gear.ID() then
                for i=1, 6 do
                    local gearType = gear.AugSlot(i).Type()
                    if gearType > 2 then
                        if gear.AugSlot(i).Empty() and gearType < 20 and gearType ~= 13 then
                            local aug = ' Slot ' .. i .. ' (Type ' .. gear.AugSlot(i).Type() .. '): \arEmpty'
                            table.insert(gearSlots, aug)
                            gearNum = gearNum + 1
                        end
                    end
                end
                if #gearSlots > 0 then
                    print(itemName, table.concat(gearSlots, ','))
                end
            end
        end
        if gearNum == 0 then
            printf('No empty slots found')
        end
    end
end

local args = {...}
ShowHelp(#args)
if #args == 1 then
    runCheck(args[1])
elseif #args == 2  then
    runCheck(args[1], args[2])
elseif #args == 3  then
    runCheck(args[1], args[2], args[3])
else
    mq.bind('/augcheck', runCheck)
    while run do
        mq.delay(1000)
    end
end

